@@ -1,4 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
+# Copyright (C) 2012-2014  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -23,15 +24,32 @@ import oz.OzException
 
 class RHEL21Guest(oz.RedHat.RedHatFDGuest):
     """
-    Class for RHEL-2.1 installation.
+    Class for RHEL-2.1 GOLD, U2, U3, U4, U5, and U6 installation.
     """
-    def __init__(self, tdl, config, auto):
-        oz.RedHat.RedHatFDGuest.__init__(self, tdl, config, auto,
-                                         "rhel-2.1-jeos.ks", "pcnet")
+    def __init__(self, tdl, config, auto, output_disk, netdev, diskbus,
+                 macaddress):
+        oz.RedHat.RedHatFDGuest.__init__(self, tdl, config, auto, output_disk,
+                                         netdev, diskbus, macaddress)
 
-def get_class(tdl, config, auto):
+    def get_auto_path(self):
+        """
+        Method to create the correct path to the RHEL 2.1 kickstart file.
+        """
+        return oz.ozutil.generate_full_auto_path("RHEL2.1.auto")
+
+def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
+              macaddress=None):
     """
     Factory method for RHEL-2.1 installs.
     """
     if tdl.update in ["GOLD", "U2", "U3", "U4", "U5", "U6"]:
-        return RHEL21Guest(tdl, config, auto)
+        if netdev is None:
+            netdev = 'pcnet'
+        return RHEL21Guest(tdl, config, auto, output_disk, netdev, diskbus,
+                           macaddress)
+
+def get_supported_string():
+    """
+    Return supported versions as a string.
+    """
+    return "RHEL 2.1: GOLD, U2, U3, U4, U5, U6"
